@@ -9,9 +9,7 @@ from typing import Optional, Sequence
 class PigAIException(Exception):
     """Armor module basic exception"""
 
-    def __init__(
-        self, msg: Optional[str] = None, stacktrace: Optional[Sequence[str]] = None
-    ):
+    def __init__(self, msg: Optional[str] = None, stacktrace: Optional[Sequence[str]] = None):
         self.msg = msg
         self.stacktrace = stacktrace
         super().__init__()
